GraphQLBuilder class

The builder class.

Constructors

GraphQLBuilder(BuilderOptions options)

Properties

buildExtensions → Map<String, List<String>>
Mapping from input file extension to output file extensions.
no setter
config → GraphQLCodegenConfig
final
hashCode → int
The hash code for this object.
no setterinherited
options → BuilderOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) → FutureOr<void>
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

wildcardPattern → RegExp
final

Static Methods

builder(BuilderOptions options) → GraphQLBuilder
A static method to initialize the builder.